[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

SF.net SVN: ledger-smb: [921] trunk



Revision: 921
          http://svn.sourceforge.net/ledger-smb/?rev=921&view=rev
Author:   einhverfr
Date:     2007-03-16 17:08:42 -0700 (Fri, 16 Mar 2007)

Log Message:
-----------
Moving from HTTP_USER_AGENT to GATEWAY_INTRFACE where appropriate

Modified Paths:
--------------
    trunk/menu.pl
    trunk/net-setup.pl

Modified: trunk/menu.pl
===================================================================
--- trunk/menu.pl	2007-03-17 00:06:37 UTC (rev 920)
+++ trunk/menu.pl	2007-03-17 00:08:42 UTC (rev 921)
@@ -156,7 +156,7 @@
 
 	if ($form->{password}) {
 		if (! Session::password_check($form, $form->{login}, $form->{password})) {
-			if ($ENV{HTTP_USER_AGENT}) {
+			if ($ENV{GATEWAY_INTERFACE}) {
 				&getpassword;
 			} else {
 				$form->error(__FILE__.':'.__LINE__.': '.$locale->text('Access Denied!'));
@@ -167,7 +167,7 @@
 		}
 		
 	} else {
-		if ($ENV{HTTP_USER_AGENT}) {
+		if ($ENV{GATEWAY_INTERFACE}) {
 			$ENV{HTTP_COOKIE} =~ s/;\s*/;/g;
 			@cookies = split /;/, $ENV{HTTP_COOKIE};
 			foreach (@cookies) {

Modified: trunk/net-setup.pl
===================================================================
--- trunk/net-setup.pl	2007-03-17 00:06:37 UTC (rev 920)
+++ trunk/net-setup.pl	2007-03-17 00:08:42 UTC (rev 921)
@@ -33,10 +33,10 @@
 
 $| = 1;
 
 #not sure how safe this is. If the browser sends a blank HTTP_USER_AGENT
 #will this script destroy part of the install? 
 #This script should probably be made inaccessible via HTTP until this feature is working
-if (($ENV{HTTP_USER_AGENT})||($ENV{HTTP_HOST})) {
+if (($ENV{GATEWAY_INTERFACE})||($ENV{HTTP_HOST})) {
 	print "Content-type: text/html\n\nThis does not work yet! use $0 from the command line";
 	exit;
 }
@@ -33,10 +33,10 @@
 $| = 1;
 
-#not sure how safe this is. If the browser sends a blank HTTP_USER_AGENT
+#not sure how safe this is. If the browser sends a blank GATEWAY_INTERFACE
 #will this script destroy part of the install? 
 #This script should probably be made inaccessible via HTTP until this feature is working


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.